| Title: | Poems of Rural Life in the Dorset Dialect |
|---|---|
| Description: | A data package containing poetry written in Dorset dialect by the likes of William Barnes. |
| Authors: | Matthew Henderson [aut, cre] |
| Maintainer: | Matthew Henderson <[email protected]> |
| License: | What license is it under? |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-10 07:39:28 UTC |
| Source: | https://github.com/MHenderson/blackmore |